@@ -1,9 +1,8 @@
-#' Plot importance ranks of best performing features from a spFSR object
+#' Ploting importance ranks of best performing features from a spFSR object
 #'
-#' @description Return a vertical bar chart of features vs. feature importance.
-#' See \link[spFSR]{spFeatureSelection} for a more detailed example.
+#' A vertical bar chart of features vs. feature importance. See \link[spFSR]{spFeatureSelection} for example.
 #'
-#' @param x an \code{spFSR} object
+#' @param x a \code{spFSR} object
 #' @param low Color for the lowest importance. The default is darkblue.
 #' @param high Color for the highest importance. The default is black.
 #'
@@ -11,13 +10,12 @@
 #'
 #' @seealso \link[spFSR]{plotImportance}, \link[spFSR]{spFSR.default}, and \link[spFSR]{spFeatureSelection}.
 #'
-#' @author Yong Kai Wong \email{yongkai1017@gmail.com}
 #' @importFrom ggplot2 ggplot
 #' @export
 plotImportance <- function(x, low = 'darkblue', high = 'black'){
 
   if( !inherits(x, 'spFSR')  ){
-    stop('Not an spFSR object.')
+    stop('Not a spFSR object.')
   }
 
   importance <- getImportance(x)
@@ -33,7 +31,7 @@ plotImportance <- function(x, low = 'darkblue', high = 'black'){
       ggplot2::labs(x = 'Variable',
                     y = 'Importance',
                     title = 'Importance Rank of Variables') +
-      ggplot2::ylim( 0, max( 0.5, max( importance$importance  ) ))
+      ggplot2::ylim( 0, max( importance$importance))
 
     print(p + ggplot2::coord_flip() )
 
